@@ -83,10 +83,10 @@ func (d *DiskIO) diskInfo(devName string) (map[string]string, error) {
 		}
 		if l[:2] == "S:" {
 			if devlinks.Len() > 0 {
-				devlinks.WriteString(" ") //nolint:revive // this will never fail
+				devlinks.WriteString(" ")
 			}
-			devlinks.WriteString("/dev/") //nolint:revive // this will never fail
-			devlinks.WriteString(l[2:])   //nolint:revive // this will never fail
+			devlinks.WriteString("/dev/")
+			devlinks.WriteString(l[2:])
 			continue
 		}
 		if l[:2] != "E:" {
