@@ -51,7 +51,7 @@ func (c *ConfigurationOriginal) Process() (map[byte]requestSet, error) {
 	if !c.workarounds.OnRequestPerField {
 		maxQuantity = maxQuantityCoils
 	}
-	coil, err := c.initRequests(c.Coils, maxQuantity)
+	coil, err := c.initRequests(c.Coils, maxQuantity, false)
 	if err != nil {
 		return nil, err
 	}
@@ -59,7 +59,7 @@ func (c *ConfigurationOriginal) Process() (map[byte]requestSet, error) {
 	if !c.workarounds.OnRequestPerField {
 		maxQuantity = maxQuantityDiscreteInput
 	}
-	discrete, err := c.initRequests(c.DiscreteInputs, maxQuantity)
+	discrete, err := c.initRequests(c.DiscreteInputs, maxQuantity, false)
 	if err != nil {
 		return nil, err
 	}
@@ -67,7 +67,7 @@ func (c *ConfigurationOriginal) Process() (map[byte]requestSet, error) {
 	if !c.workarounds.OnRequestPerField {
 		maxQuantity = maxQuantityHoldingRegisters
 	}
-	holding, err := c.initRequests(c.HoldingRegisters, maxQuantity)
+	holding, err := c.initRequests(c.HoldingRegisters, maxQuantity, true)
 	if err != nil {
 		return nil, err
 	}
@@ -75,7 +75,7 @@ func (c *ConfigurationOriginal) Process() (map[byte]requestSet, error) {
 	if !c.workarounds.OnRequestPerField {
 		maxQuantity = maxQuantityInputRegisters
 	}
-	input, err := c.initRequests(c.InputRegisters, maxQuantity)
+	input, err := c.initRequests(c.InputRegisters, maxQuantity, true)
 	if err != nil {
 		return nil, err
 	}
@@ -90,21 +90,27 @@ func (c *ConfigurationOriginal) Process() (map[byte]requestSet, error) {
 	}, nil
 }
 
-func (c *ConfigurationOriginal) initRequests(fieldDefs []fieldDefinition, maxQuantity uint16) ([]request, error) {
-	fields, err := c.initFields(fieldDefs)
+func (c *ConfigurationOriginal) initRequests(fieldDefs []fieldDefinition, maxQuantity uint16, typed bool) ([]request, error) {
+	fields, err := c.initFields(fieldDefs, typed)
 	if err != nil {
 		return nil, err
 	}
-	return groupFieldsToRequests(fields, nil, maxQuantity, "none", 0), nil
+	params := groupingParams{
+		MaxBatchSize:    maxQuantity,
+		Optimization:    "none",
+		EnforceFromZero: c.workarounds.ReadCoilsStartingAtZero,
+	}
+
+	return groupFieldsToRequests(fields, params), nil
 }
 
-func (c *ConfigurationOriginal) initFields(fieldDefs []fieldDefinition) ([]field, error) {
+func (c *ConfigurationOriginal) initFields(fieldDefs []fieldDefinition, typed bool) ([]field, error) {
 	// Construct the fields from the field definitions
 	fields := make([]field, 0, len(fieldDefs))
 	for _, def := range fieldDefs {
-		f, err := c.newFieldFromDefinition(def)
+		f, err := c.newFieldFromDefinition(def, typed)
 		if err != nil {
-			return nil, fmt.Errorf("initializing field %q failed: %v", def.Name, err)
+			return nil, fmt.Errorf("initializing field %q failed: %w", def.Name, err)
 		}
 		fields = append(fields, f)
 	}
@@ -112,7 +118,7 @@ func (c *ConfigurationOriginal) initFields(fieldDefs []fieldDefinition) ([]field
 	return fields, nil
 }
 
-func (c *ConfigurationOriginal) newFieldFromDefinition(def fieldDefinition) (field, error) {
+func (c *ConfigurationOriginal) newFieldFromDefinition(def fieldDefinition, typed bool) (field, error) {
 	// Check if the addresses are consecutive
 	expected := def.Address[0]
 	for _, current := range def.Address[1:] {
@@ -129,6 +135,17 @@ func (c *ConfigurationOriginal) newFieldFromDefinition(def fieldDefinition) (fie
 		address:     def.Address[0],
 		length:      uint16(len(def.Address)),
 	}
+
+	// Handle coil and discrete registers which do have a limited datatype set
+	if !typed {
+		var err error
+		f.converter, err = determineUntypedConverter(def.DataType)
+		if err != nil {
+			return field{}, err
+		}
+		return f, nil
+	}
+
 	if def.DataType != "" {
 		inType, err := c.normalizeInputDatatype(def.DataType, len(def.Address))
 		if err != nil {
@@ -188,6 +205,13 @@ func (c *ConfigurationOriginal) validateFieldDefinitions(fieldDefs []fieldDefini
 			if item.Scale == 0.0 {
 				return fmt.Errorf("invalid scale '%f' in %q - %q", item.Scale, registerType, item.Name)
 			}
+		} else {
+			// Bit-registers do have less data types
+			switch item.DataType {
+			case "", "UINT16", "BOOL":
+			default:
+				return fmt.Errorf("invalid data type %q in %q - %q", item.DataType, registerType, item.Name)
+			}
 		}
 
 		// check address
