@@ -6,16 +6,25 @@ import (
 	"time"
 
 	"github.com/influxdata/influxdb-observability/common"
+	"github.com/influxdata/influxdb-observability/otel2influx"
 
 	"github.com/influxdata/telegraf"
 )
 
+var (
+	_ otel2influx.InfluxWriter      = (*writeToAccumulator)(nil)
+	_ otel2influx.InfluxWriterBatch = (*writeToAccumulator)(nil)
+)
+
 type writeToAccumulator struct {
 	accumulator telegraf.Accumulator
 }
 
-func (w *writeToAccumulator) WritePoint(
-	_ context.Context,
+func (w *writeToAccumulator) NewBatch() otel2influx.InfluxWriterBatch {
+	return w
+}
+
+func (w *writeToAccumulator) EnqueuePoint(
 	measurement string,
 	tags map[string]string,
 	fields map[string]interface{},
@@ -38,3 +47,7 @@ func (w *writeToAccumulator) WritePoint(
 	}
 	return nil
 }
+
+func (w *writeToAccumulator) WriteBatch(_ context.Context) error {
+	return nil
+}
