@@ -11,7 +11,6 @@ import (
 	"github.com/influxdata/telegraf"
 	"github.com/influxdata/telegraf/internal"
 	"github.com/influxdata/telegraf/plugins/inputs"
-	"github.com/influxdata/telegraf/plugins/parsers"
 	"github.com/influxdata/telegraf/selfstat"
 )
 
@@ -44,7 +43,7 @@ type TCPListener struct {
 	// track current connections so we can close them in Stop()
 	conns map[string]*net.TCPConn
 
-	parser parsers.Parser
+	parser telegraf.Parser
 	acc    telegraf.Accumulator
 
 	MaxConnections     selfstat.Stat
@@ -73,7 +72,7 @@ func (t *TCPListener) Gather(_ telegraf.Accumulator) error {
 	return nil
 }
 
-func (t *TCPListener) SetParser(parser parsers.Parser) {
+func (t *TCPListener) SetParser(parser telegraf.Parser) {
 	t.parser = parser
 }
 
