@@ -16,6 +16,7 @@ import (
 	"time"
 
 	"github.com/influxdata/telegraf"
+	"github.com/influxdata/telegraf/config"
 	"github.com/influxdata/telegraf/internal"
 	"github.com/influxdata/telegraf/plugins/serializers/influx"
 )
@@ -88,8 +89,8 @@ type HTTPConfig struct {
 	URL                       *url.URL
 	UserAgent                 string
 	Timeout                   time.Duration
-	Username                  string
-	Password                  string
+	Username                  config.Secret
+	Password                  config.Secret
 	TLSConfig                 *tls.Config
 	Proxy                     *url.URL
 	Headers                   map[string]string
@@ -154,7 +155,10 @@ func NewHTTPClient(cfg HTTPConfig) (*httpClient, error) {
 	}
 
 	if cfg.Serializer == nil {
-		cfg.Serializer = influx.NewSerializer()
+		cfg.Serializer = &influx.Serializer{}
+		if err := cfg.Serializer.Init(); err != nil {
+			return nil, err
+		}
 	}
 
 	var transport *http.Transport
@@ -204,6 +208,7 @@ func (c *httpClient) Database() string {
 // Note that some names are not allowed by the server, notably those with
 // non-printable characters or slashes.
 func (c *httpClient) CreateDatabase(ctx context.Context, database string) error {
+	//nolint:gocritic // sprintfQuotedString - "%s" used by purpose, string escaping is done by special function
 	query := fmt.Sprintf(`CREATE DATABASE "%s"`, escapeIdentifier.Replace(database))
 
 	req, err := c.makeQueryRequest(query)
@@ -329,7 +334,7 @@ func (c *httpClient) Write(ctx context.Context, metrics []telegraf.Metric) error
 func (c *httpClient) writeBatch(ctx context.Context, db, rp string, metrics []telegraf.Metric) error {
 	loc, err := makeWriteURL(c.config.URL, db, rp, c.config.Consistency)
 	if err != nil {
-		return fmt.Errorf("failed making write url: %s", err.Error())
+		return fmt.Errorf("failed making write url: %w", err)
 	}
 
 	reader := c.requestBodyReader(metrics)
@@ -337,13 +342,13 @@ func (c *httpClient) writeBatch(ctx context.Context, db, rp string, metrics []te
 
 	req, err := c.makeWriteRequest(loc, reader)
 	if err != nil {
-		return fmt.Errorf("failed making write req: %s", err.Error())
+		return fmt.Errorf("failed making write req: %w", err)
 	}
 
 	resp, err := c.client.Do(req.WithContext(ctx))
 	if err != nil {
 		internal.OnClientError(c.client, err)
-		return fmt.Errorf("failed doing req: %s", err.Error())
+		return fmt.Errorf("failed doing req: %w", err)
 	}
 	defer resp.Body.Close()
 
@@ -448,9 +453,11 @@ func (c *httpClient) makeQueryRequest(query string) (*http.Request, error) {
 	}
 
 	req.Header.Set("Content-Type", "application/x-www-form-urlencoded")
-	c.addHeaders(req)
+	if err := c.addHeaders(req); err != nil {
+		return nil, err
+	}
 
-	return req, nil
+	return req, err
 }
 
 func (c *httpClient) makeWriteRequest(address string, body io.Reader) (*http.Request, error) {
@@ -458,11 +465,13 @@ func (c *httpClient) makeWriteRequest(address string, body io.Reader) (*http.Req
 
 	req, err := http.NewRequest("POST", address, body)
 	if err != nil {
-		return nil, fmt.Errorf("failed creating new request: %s", err.Error())
+		return nil, fmt.Errorf("failed creating new request: %w", err)
 	}
 
 	req.Header.Set("Content-Type", "text/plain; charset=utf-8")
-	c.addHeaders(req)
+	if err := c.addHeaders(req); err != nil {
+		return nil, err
+	}
 
 	if c.config.ContentEncoding == "gzip" {
 		req.Header.Set("Content-Encoding", "gzip")
@@ -483,14 +492,27 @@ func (c *httpClient) requestBodyReader(metrics []telegraf.Metric) io.ReadCloser
 	return io.NopCloser(reader)
 }
 
-func (c *httpClient) addHeaders(req *http.Request) {
-	if c.config.Username != "" || c.config.Password != "" {
-		req.SetBasicAuth(c.config.Username, c.config.Password)
+func (c *httpClient) addHeaders(req *http.Request) error {
+	if !c.config.Username.Empty() || !c.config.Password.Empty() {
+		username, err := c.config.Username.Get()
+		if err != nil {
+			return fmt.Errorf("getting username failed: %w", err)
+		}
+		password, err := c.config.Password.Get()
+		if err != nil {
+			config.ReleaseSecret(username)
+			return fmt.Errorf("getting password failed: %w", err)
+		}
+		req.SetBasicAuth(string(username), string(password))
+		config.ReleaseSecret(username)
+		config.ReleaseSecret(password)
 	}
 
 	for header, value := range c.config.Headers {
 		req.Header.Set(header, value)
 	}
+
+	return nil
 }
 
 func (c *httpClient) validateResponse(response io.ReadCloser) (io.ReadCloser, error) {
