@@ -84,10 +84,6 @@ func (p *Parser) SetDefaultTags(tags map[string]string) {
 	p.DefaultTags = tags
 }
 
-func (p *Parser) InitFromConfig(_ *parsers.Config) error {
-	return nil
-}
-
 func init() {
 	parsers.Add("prometheusremotewrite",
 		func(defaultMetricName string) telegraf.Parser {
