@@ -2,6 +2,7 @@ package ec2
 
 import (
 	"testing"
+	"time"
 
 	"github.com/influxdata/telegraf/config"
 	"github.com/influxdata/telegraf/testutil"
@@ -31,6 +32,30 @@ func TestBasicStartupWithEC2Tags(t *testing.T) {
 	require.Len(t, acc.Errors, 0)
 }
 
+func TestBasicStartupWithCacheTTL(t *testing.T) {
+	p := newAwsEc2Processor()
+	p.Log = &testutil.Logger{}
+	p.ImdsTags = []string{"accountId", "instanceId"}
+	p.CacheTTL = config.Duration(12 * time.Hour)
+	acc := &testutil.Accumulator{}
+	require.NoError(t, p.Init())
+
+	require.Len(t, acc.GetTelegrafMetrics(), 0)
+	require.Len(t, acc.Errors, 0)
+}
+
+func TestBasicStartupWithTagCacheSize(t *testing.T) {
+	p := newAwsEc2Processor()
+	p.Log = &testutil.Logger{}
+	p.ImdsTags = []string{"accountId", "instanceId"}
+	p.TagCacheSize = 100
+	acc := &testutil.Accumulator{}
+	require.NoError(t, p.Init())
+
+	require.Len(t, acc.GetTelegrafMetrics(), 0)
+	require.Len(t, acc.Errors, 0)
+}
+
 func TestBasicInitNoTagsReturnAnError(t *testing.T) {
 	p := newAwsEc2Processor()
 	p.Log = &testutil.Logger{}
@@ -46,12 +71,3 @@ func TestBasicInitInvalidTagsReturnAnError(t *testing.T) {
 	err := p.Init()
 	require.Error(t, err)
 }
-
-func TestLoadingConfig(t *testing.T) {
-	confFile := []byte("[[processors.aws_ec2]]" + "\n" + sampleConfig)
-	c := config.NewConfig()
-	err := c.LoadConfigData(confFile)
-	require.NoError(t, err)
-
-	require.Len(t, c.Processors, 1)
-}
