@@ -14,6 +14,7 @@ import (
 	"github.com/stretchr/testify/require"
 
 	"github.com/influxdata/telegraf"
+	"github.com/influxdata/telegraf/config"
 	"github.com/influxdata/telegraf/metric"
 	"github.com/influxdata/telegraf/plugins/parsers/influx"
 	"github.com/influxdata/telegraf/testutil"
@@ -29,8 +30,8 @@ func TestSerializeMetricFloat(t *testing.T) {
 	}
 	m := metric.New("cpu", tags, fields, now)
 
-	s, err := NewSerializer(FormatConfig{})
-	require.NoError(t, err)
+	s := Serializer{}
+	require.NoError(t, s.Init())
 	buf, err := s.Serialize(m)
 	require.NoError(t, err)
 	expS := []byte(fmt.Sprintf(`{"fields":{"usage_idle":91.5},"name":"cpu","tags":{"cpu":"cpu0"},"timestamp":%d}`, now.Unix()) + "\n")
@@ -90,11 +91,11 @@ func TestSerialize_TimestampUnits(t *testing.T) {
 				},
 				time.Unix(1525478795, 123456789),
 			)
-			s, err := NewSerializer(FormatConfig{
-				TimestampUnits:  tt.timestampUnits,
+			s := Serializer{
+				TimestampUnits:  config.Duration(tt.timestampUnits),
 				TimestampFormat: tt.timestampFormat,
-			})
-			require.NoError(t, err)
+			}
+			require.NoError(t, s.Init())
 			actual, err := s.Serialize(m)
 			require.NoError(t, err)
 			require.Equal(t, tt.expected+"\n", string(actual))
@@ -112,8 +113,8 @@ func TestSerializeMetricInt(t *testing.T) {
 	}
 	m := metric.New("cpu", tags, fields, now)
 
-	s, err := NewSerializer(FormatConfig{})
-	require.NoError(t, err)
+	s := Serializer{}
+	require.NoError(t, s.Init())
 	buf, err := s.Serialize(m)
 	require.NoError(t, err)
 
@@ -131,8 +132,8 @@ func TestSerializeMetricString(t *testing.T) {
 	}
 	m := metric.New("cpu", tags, fields, now)
 
-	s, err := NewSerializer(FormatConfig{})
-	require.NoError(t, err)
+	s := Serializer{}
+	require.NoError(t, s.Init())
 	buf, err := s.Serialize(m)
 	require.NoError(t, err)
 
@@ -151,8 +152,8 @@ func TestSerializeMultiFields(t *testing.T) {
 	}
 	m := metric.New("cpu", tags, fields, now)
 
-	s, err := NewSerializer(FormatConfig{})
-	require.NoError(t, err)
+	s := Serializer{}
+	require.NoError(t, s.Init())
 	buf, err := s.Serialize(m)
 	require.NoError(t, err)
 
@@ -170,8 +171,8 @@ func TestSerializeMetricWithEscapes(t *testing.T) {
 	}
 	m := metric.New("My CPU", tags, fields, now)
 
-	s, err := NewSerializer(FormatConfig{})
-	require.NoError(t, err)
+	s := Serializer{}
+	require.NoError(t, s.Init())
 	buf, err := s.Serialize(m)
 	require.NoError(t, err)
 
@@ -188,10 +189,10 @@ func TestSerializeBatch(t *testing.T) {
 		},
 		time.Unix(0, 0),
 	)
-
 	metrics := []telegraf.Metric{m, m}
-	s, err := NewSerializer(FormatConfig{})
-	require.NoError(t, err)
+
+	s := Serializer{}
+	require.NoError(t, s.Init())
 	buf, err := s.SerializeBatch(metrics)
 	require.NoError(t, err)
 	require.Equal(
@@ -214,8 +215,8 @@ func TestSerializeBatchSkipInf(t *testing.T) {
 		),
 	}
 
-	s, err := NewSerializer(FormatConfig{})
-	require.NoError(t, err)
+	s := Serializer{}
+	require.NoError(t, s.Init())
 	buf, err := s.SerializeBatch(metrics)
 	require.NoError(t, err)
 	require.Equal(t, []byte(`{"metrics":[{"fields":{"time_idle":42},"name":"cpu","tags":{},"timestamp":0}]}`), buf)
@@ -233,8 +234,8 @@ func TestSerializeBatchSkipInfAllFields(t *testing.T) {
 		),
 	}
 
-	s, err := NewSerializer(FormatConfig{})
-	require.NoError(t, err)
+	s := Serializer{}
+	require.NoError(t, s.Init())
 	buf, err := s.SerializeBatch(metrics)
 	require.NoError(t, err)
 	require.Equal(t, []byte(`{"metrics":[{"fields":{},"name":"cpu","tags":{},"timestamp":0}]}`), buf)
@@ -269,13 +270,13 @@ func TestSerializeTransformationNonBatch(t *testing.T) {
 			expected := expectedArray.([]interface{})
 
 			// Serialize
-			serializer, err := NewSerializer(
-				FormatConfig{
-					TimestampUnits:  cfg.TimestampUnits,
-					TimestampFormat: cfg.TimestampFormat,
-					Transformation:  cfg.Transformation,
-				})
-			require.NoError(t, err)
+			serializer := Serializer{
+				TimestampUnits:  config.Duration(cfg.TimestampUnits),
+				TimestampFormat: cfg.TimestampFormat,
+				Transformation:  cfg.Transformation,
+			}
+			require.NoError(t, serializer.Init())
+
 			for i, m := range metrics {
 				buf, err := serializer.Serialize(m)
 				require.NoError(t, err)
@@ -317,13 +318,13 @@ func TestSerializeTransformationBatch(t *testing.T) {
 			require.NoError(t, err)
 
 			// Serialize
-			serializer, err := NewSerializer(
-				FormatConfig{
-					TimestampUnits:  cfg.TimestampUnits,
-					TimestampFormat: cfg.TimestampFormat,
-					Transformation:  cfg.Transformation,
-				})
-			require.NoError(t, err)
+			serializer := Serializer{
+				TimestampUnits:  config.Duration(cfg.TimestampUnits),
+				TimestampFormat: cfg.TimestampFormat,
+				Transformation:  cfg.Transformation,
+			}
+			require.NoError(t, serializer.Init())
+
 			buf, err := serializer.SerializeBatch(metrics)
 			require.NoError(t, err)
 
@@ -335,6 +336,65 @@ func TestSerializeTransformationBatch(t *testing.T) {
 	}
 }
 
+func TestSerializeTransformationIssue12734(t *testing.T) {
+	input := []telegraf.Metric{
+		metric.New(
+			"data",
+			map[string]string{"key": "a"},
+			map[string]interface{}{"value": 10.1},
+			time.Unix(0, 1676285135457000000),
+		),
+		metric.New(
+			"data",
+			map[string]string{"key": "b"},
+			map[string]interface{}{"value": 20.2},
+			time.Unix(0, 1676285135457000000),
+		),
+		metric.New(
+			"data",
+			map[string]string{"key": "c"},
+			map[string]interface{}{"value": 30.3},
+			time.Unix(0, 1676285135457000000),
+		),
+	}
+
+	transformation := `
+	{
+		"valueRows": metrics{$string(timestamp): fields.value[]} ~> $each(function($v, $k) {
+			{
+				"timestamp": $number($k),
+				"values": $v
+			}
+		})
+	}
+	`
+
+	expected := map[string]interface{}{
+		"valueRows": map[string]interface{}{
+			"timestamp": 1.676285135e+9,
+			"values":    []interface{}{10.1, 20.2, 30.3},
+		},
+	}
+
+	// Setup serializer
+	serializer := Serializer{
+		Transformation: transformation,
+	}
+	require.NoError(t, serializer.Init())
+
+	// Check multiple serializations as issue #12734 shows that the
+	// transformation breaks after the first iteration
+	for i := 1; i <= 3; i++ {
+		buf, err := serializer.SerializeBatch(input)
+		require.NoErrorf(t, err, "broke in iteration %d", i)
+
+		// Compare
+		var actual interface{}
+		require.NoError(t, json.Unmarshal(buf, &actual))
+		require.EqualValuesf(t, expected, actual, "broke in iteration %d", i)
+	}
+}
+
 func TestSerializeNesting(t *testing.T) {
 	var tests = []struct {
 		name     string
@@ -372,15 +432,14 @@ func TestSerializeNesting(t *testing.T) {
 			expected := expectedArray.(map[string]interface{})
 
 			// Serialize
-			serializer, err := NewSerializer(
-				FormatConfig{
-					TimestampUnits:      cfg.TimestampUnits,
-					TimestampFormat:     cfg.TimestampFormat,
-					Transformation:      cfg.Transformation,
-					NestedFieldsInclude: cfg.JSONNestedFieldsInclude,
-					NestedFieldsExclude: cfg.JSONNestedFieldsExclude,
-				})
-			require.NoError(t, err)
+			serializer := Serializer{
+				TimestampUnits:      config.Duration(cfg.TimestampUnits),
+				TimestampFormat:     cfg.TimestampFormat,
+				Transformation:      cfg.Transformation,
+				NestedFieldsInclude: cfg.JSONNestedFieldsInclude,
+				NestedFieldsExclude: cfg.JSONNestedFieldsExclude,
+			}
+			require.NoError(t, serializer.Init())
 
 			buf, err := serializer.Serialize(metrics[0])
 			require.NoError(t, err)
